@@ -2,10 +2,11 @@
 
 ;; Copyright (C) 1998, 2013 Free Software Foundation, Inc.
 
-;; Author: Glynn Clements <glynn.clements@virgin.net>
-;; Version: 1.04
+;; Author: Glynn Clements <glynn.clements@xemacs.org>
+;; Version: 1.4
 ;; Created: 1997-09-11
 ;; Keywords: games
+;; Package-Type: multi
 
 ;; This file is part of XEmacs.
 
@@ -428,7 +429,9 @@ static char * player_xpm[] = {
 (defun sokoban-init-level-data ()
   (setq sokoban-level-data nil)
   (with-current-buffer (find-file-noselect sokoban-level-file)
-    (read-only-mode 1)
+    (if (fboundp 'read-only-mode)
+        (read-only-mode 1)
+      (setq buffer-read-only t))
     (goto-char (point-min))
     (re-search-forward sokoban-level-regexp nil t)
     (forward-char)
